@echo off

echo Installing GEM...

echo Copying examples...
copy examples\* ..\examples > tempInstall.trash
echo Copying documentation...
copy doc\gem*.* ..\doc > tempInstall.trash
echo Copying help files...
copy help\* ..\test > tempInstall.trash

del tempInstall.trash

echo Install finished.
