#! /bin/sh
#
# Install GEM
#
# Mark Danks - mdanks@cybermed.ucsd.edu
#

echo Installing GEM...

echo Copying examples...
cp examples/* ../examples
echo Copying documentation...
cp doc/* ../doc
echo Copying help files...
cp help/* ../test


